<?php
/**
* @package		EasySocial
* @copyright	Copyright (C) 2010 - 2018 Stack Ideas Sdn Bhd. All rights reserved.
* @license		GNU/GPL, see LICENSE.php
* EasySocial is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

ES::import('admin:/tables/table');

class NotesTableNote extends SocialTable
{
	public $id = null;
	public $user_id	= null;
	public $title = null;
	public $alias = null;
	public $content	= null;
	public $created	= null;
	public $params = null;

	public function __construct(& $db)
	{
		parent::__construct('#__social_notes', 'id', $db);
	}

	public function store($updateNulls = false)
	{
		// @TODO: Automatically set the alias
		if (!$this->alias) {

		}

		$state = parent::store();

		return $state;
	}

	public function getAppId()
	{
		return $this->getApp()->id;
	}

	public function getApp()
	{
		static $app;

		if (empty($app)) {
			$app = ES::table('app');
			$app->load(array('type' => SOCIAL_TYPE_APPS, 'group' => SOCIAL_APPS_GROUP_USER, 'element' => 'notes'));
		}

		return $app;
	}

	/**
	 * Formats the content of a note
	 *
	 * @since	1.2
	 * @access	public
	 */
	public function getContent()
	{
		// Apply e-mail replacements
		$content = ES::string()->replaceEmails($this->content);

		// Apply hyperlinks
		$content = ES::string()->replaceHyperlinks($content);

		// Apply bbcode
		$content = ES::string()->parseBBCode($content, array('code' => true, 'escape' => false));

		return $content;
	}

	/**
	 * Creates a new stream record
	 *
	 * @since	1.0
	 * @access	public
	 */
	public function createStream($verb, $state = true)
	{
		// Add activity logging when a friend connection has been made.
		// Activity logging.
		$stream	= ES::stream();
		$streamTemplate	= $stream->getTemplate();

		// Set the actor.
		$streamTemplate->setActor($this->user_id, SOCIAL_TYPE_USER);

		// Set the context.
		$streamTemplate->setContext($this->id, 'notes');

		// Set the verb.
		$streamTemplate->setVerb($verb);

		$streamTemplate->setAccess('core.view');

		// set publishing state of the stream
		$streamTemplate->setState($state);

		// Create the stream data.
		$stream->add($streamTemplate);
	}

	/**
	 * Overrides parent's delete behavior
	 *
	 * @since	1.0
	 * @access	public
	 */
	public function delete($pk = null)
	{
		$db = ES::db();

		// delete comments and reactions.
		$query = "delete b, c";
		$query .= " from `#__social_notes` as a";
		// remove all associated comments;
		$query .= " left join `#__social_comments` as b on a.`id` = b.`uid` and b.`element` LIKE " . $db->Quote('notes.%');
		// remove all associated reaction;
		$query .= " left join `#__social_likes` as c on a.`id` = c.`uid` and c.`type` LIKE " . $db->Quote('notes.%');
		$query .= " where a.`id` = " . $db->Quote($this->id);

		$db->setQuery($query);
		$db->query();

		$state = parent::delete($pk);

		// Delete streams that are related to this note.
		$stream = ES::stream();
		$stream->delete($this->id, 'notes');

		return $state;
	}

	/**
	 * Shorthand to get the permalink of this note.
	 *
	 * @since  1.2
	 * @access public
	 */
	public function getPermalink($external = false, $xhtml = true, $sef = true, $adminSef = false)
	{
		return $this->getApp()->getCanvasUrl(array('cid' => $this->id, 'uid' => ES::user($this->user_id)->getAlias(), 'type' => SOCIAL_TYPE_USER, 'external' => $external, 'sef' => $sef, 'adminSef' => $adminSef), $xhtml);
	}

	/**
	 * Method to export the data for REST API
	 *
	 * @since	3.1.0
	 * @access	public
	 */
	public function toExportData($viewer)
	{
		$properties = get_object_vars($this);

		$note = array();

		foreach ($properties as $key => $value) {
			if ($key[0] != '_') {
				$note[$key] = $value;
			}
		}

		return $note;
	}
}
